@@ -1,11 +1,6 @@
 package Lingua::YaTeA::IndexSet;
 use strict;
-use warnings;
-use UNIVERSAL;
-use Scalar::Util qw(blessed);
-
-our $VERSION=$Lingua::YaTeA::VERSION;
-
+use UNIVERSAL qw(isa);
 sub new
 {
     my ($class,$words_a) = @_;
@@ -82,8 +77,9 @@ sub searchSubIndexesSet
     for ($i = 1; $i <= $max; $i++)
     {
 	$sub_index = $this->searchSubIndexes($i,$words_a,$this->getSize,$chunking_data,$tag_set);
-	if ((blessed($sub_index)) && ($sub_index->isa('Lingua::YaTeA::IndexSet'))) { # the substring is valid
+	if(isa($sub_index,'Lingua::YaTeA::IndexSet')){ # the substring is valid
 	    push @sub_indexes_set, $sub_index;
+	    
 	}
     }
    
@@ -154,7 +150,7 @@ sub isDisjuncted
 
 sub getIncluded
 {
-    my ($this,$other_index_sets_a,$parsing_direction) = @_;
+    my ($this,$other_index_sets_a) = @_;
     my $index_set;
     my @included;
     foreach $index_set (@{$other_index_sets_a})
@@ -170,24 +166,10 @@ sub getIncluded
 	    push @included, $index_set;
 	}
     }
-    $this->sortIncluded(\@included, $parsing_direction);
     return \@included;
 }
 
 
-sub sortIncluded
-{
-    my ($this,$included_index_sets_a,$parsing_direction) = @_;
-    if($parsing_direction eq "RIGHT")
-    {
-	@$included_index_sets_a = sort ({$b->getLast <=> $a->getLast} @$included_index_sets_a);
-    }
-    else
-    {
-	@$included_index_sets_a = sort ({$b->getFirst <=> $b->getFirst} @$included_index_sets_a);
-    }
-}
-
 sub isIncluded
 {
     my ($this,$other_index,$pivot) = @_;
@@ -422,7 +404,7 @@ sub testSyntacticBreakAndRepetition
 	{
 	    while(($j+1) < $this->getIndex($i))
 	    {
-		if($tag_set->existTag('PREPOSITIONS',$words_a->[($j+1)]->getIF)) # XXX TH 07/01/2008
+		if($tag_set->existTag('PREPOSITIONS',$words_a->[($j+1)]->getLF))
 		{
 		    return;
 		}
@@ -446,48 +428,6 @@ sub testSyntacticBreakAndRepetition
 
 }
 
-
-sub testSyntacticBreak
-{
-    my ($this,$words_a,$tag_set) = @_;
-    my @absent;
-    my $i;
-    my %words;
-    my $j = $this->getFirst;
-
-    for($i = 1; $i < $this->getSize; $i++)
-    {
-	$words{$words_a->[$j]->getLF}++;
-		
-	if($this->getIndex($i) != ($j+1))
-	{
-	    while(($j+1) < $this->getIndex($i))
-	    {
-		if($tag_set->existTag('PREPOSITIONS',$words_a->[($j+1)]->getIF)) # XXX TH 07/01/2008
-		{
-		    return;
-		}
-		if($tag_set->existTag('CANDIDATES',$words_a->[($j+1)]->getPOS))
-		{
-		    if (exists $words{$words_a->[($j+1)]->getLF})
-		    {
-			return;
-		    }
-		}
-		
-		$j++;	    
-	    }
-	}
-	else
-	{
-	    $j++;
-	}
-    }
-    return 1;
-
-}
-
-
 sub buildIFSequence
 {
     my ($this,$words_a) = @_;
@@ -508,7 +448,7 @@ sub buildPOSSequence
     my $index;
     foreach $index (@{$this->getIndexes})
     {
-	if ($tag_set->existTag('PREPOSITIONS',$words_a->[$index]->getIF)) # XXX TH 07/01/2008
+	if ($tag_set->existTag('PREPOSITIONS',$words_a->[$index]->getLF))
 	{
 	    $POS .= $words_a->[$index]->getLF . " ";
 	}
@@ -623,133 +563,56 @@ sub getPartial
 
 sub simplify
 {
-    my ($this,$partial_index_set,$node_set,$tree,$pivot,$fh) = @_;
+    my ($this,$partial_index_set,$node_set,$tree,$pivot) = @_;
     my $i;
     my $j=0;
     my $index;
     my $index_partial;
     my @simplified;
-    if(defined $fh)
-    {
-# 	print $fh "arbre:";
-# 	$tree->getIndexSet->print($fh);
-# 	print $fh "\nsimplifie:";
-# 	$this->print($fh);
-# 	print $fh "\npartial:";
-# 	$partial_index_set->print($fh);
-# 	if(defined $pivot)
-# 	{
-# 	    print $fh "\n";
-# 	    print $fh "pivot :" .$pivot ."\n";
-# 	}
-    }
+    
     for ($i= 0; $i < scalar @{$this->getIndexes}; $i++)
     {
 	$index = $this->getIndex($i);
-	
-# 	if(defined $fh)
-# 	{
-# 	    print $fh "index  :" . $index . "\n";
-# 	}
 	if($j < scalar @{$partial_index_set->getIndexes})
 	{
-	    &simplifyByCurrent(\$j,\@simplified,$index,$partial_index_set,$node_set,$tree,$pivot,$fh);
+	    $index_partial  = $partial_index_set->getIndex($j);
+	    if($index == $index_partial)
+	    {
+		if(
+		    (
+		     (!defined $pivot)
+		     ||
+		     ($index != $pivot)
+		    )
+		    &&
+		    (! $tree->getIndexSet->indexExists($index))
+		    )
+		{
+		    $tree->getIndexSet->addIndex($index);
+		}
+		if($index_partial == $node_set->getRoot->searchHead->getIndex)
+		{
+		    push  @simplified, $index_partial;
+		    
+		}
+		$j++;
+	    }
+	    
+	    else
+	    {
+		push  @simplified, $index;
+	    }
 	}
 	else
 	{
-# 	    if(defined $fh)
-# 	    {
-# 		print $fh "push2 dans simplified " . $index . "\n";
-# 	    }
 	    push  @simplified, $index;
 	}
 	
     }
     @{$this->getIndexes} = @simplified;
-#     if(defined $fh)
-#     {
-# 	print $fh "apres\n";
-# 	print $fh "arbre:";
-# 	$tree->getIndexSet->print($fh);
-# 	print $fh "\nsimplifie:";
-# 	$this->print($fh);
-# 	print $fh "\npartial:";
-# 	$partial_index_set->print($fh);
-# 	print $fh "\n";
-#     }
 
 }
 
-
-sub simplifyByCurrent
-{
-    my ($j_s,$simplified_a,$index,$partial_index_set,$node_set,$tree,$pivot,$fh) = @_;
-    my $index_partial  = $partial_index_set->getIndex($$j_s);
-    while (
-	   ($index_partial < $index)
-	   &&
-	   ($tree->getIndexSet->indexExists($index_partial))
-	   &&
-	   ($$j_s < scalar @{$partial_index_set->getIndexes} -1)
-	   )
-    {
-	$$j_s++;
-	$index_partial  = $partial_index_set->getIndex($$j_s);
-    }
- #    if(defined $fh)
-#     {
-# 	print $fh "\tindex partiel :" . $index_partial . "\n";
-#     }
-    
-    if($index == $index_partial)
-    {
-	if(
-	   (
-	    (!defined $pivot)
-	    ||
-	    ($index != $pivot)
-	    )
-	   &&
-	   (! $tree->getIndexSet->indexExists($index))
-	   )
-	{
-	    $tree->getIndexSet->addIndex($index);
-	  #   if(defined $fh)
-# 	    {
-# 		print $fh "ajoute a iindex d'arbre :" . $index . "\n";
-# 	    }
-	}
-	# hack from TH
-	my $head = $node_set->getRoot->searchHead(0);
-	if((ref($head) ne "SCALAR") && (defined $head)) {
-	    if ($index_partial == $head->getIndex)
-	    {
-		push  @$simplified_a, $index_partial;
-		
-	    }
-	} else {
-	    warn "The head is undefined\n";
-	    return(-1);
-	}
-	
-	$$j_s++;
-# 	if(defined $fh)
-# 	{
-# 	    print $fh "incerementation j" . $$j_s . "\n";
-# 	}
-    }
-    
-    else
-    {
-# 	if(defined $fh)
-# 	{
-# 	    print $fh "push dans simplified " . $index . "\n";
-# 	}
-	push  @$simplified_a, $index;
-    }
-}
-
-
 sub simplifyWithSeveralPivots
 {
     my ($this,$partial_index_set,$node_set,$tree,$pivots_h) = @_;
@@ -919,107 +782,86 @@ sub removeIndex
 
 sub defineAppendMode
 {
-    my ($this,$to_append,$pivot,$fh) = @_;
+    my ($this,$to_append,$pivot) = @_;
     my $mode;
-# if(defined $fh)
-# {
-#     print $fh "-> this\n";
-#     print $fh $this->getFirst . "\n";
-#     print $fh $this->getLast . "\n";
-#     print $fh "-> to append\n";
-#     print $fh $to_append->getFirst . "\n";
-#     print $fh $to_append->getLast . "\n";
-# }
 
-    if (defined @{$this->getIndexes}) {
-	if(
-	   ($this->getLast < $to_append->getFirst)
-	   ||
-	   ($this->getFirst > $to_append->getLast)
-	   )
-	{    
-	#     if(defined $fh)
-# 	    {
-# 		print $fh "dis 1 \n";
-# 	    }
-	    return "DISJUNCTION"; # external disjunction
-	}
-	
-	if(
-	   ($this->getLast == $to_append->getFirst)
-	   ||
-	   ($this->getFirst == $to_append->getLast)
-	   )
-	{
-	    return "ADJUNCTION";
-	}
+    if(
+	($this->getLast < $to_append->getFirst)
+	||
+	($this->getFirst > $to_append->getLast)
+	)
+    {    
+	return "DISJUNCTION"; # external disjunction
+    }
 
-	if($this->getFirst <= $to_append->getFirst)
+    if(
+	($this->getLast == $to_append->getFirst)
+	||
+	($this->getFirst == $to_append->getLast)
+	)
+    {
+	return "ADJUNCTION";
+    }
+
+    if($this->getFirst <= $to_append->getFirst)
+    {
+	if($this->getLast >= $to_append->getLast)
 	{
-	    if($this->getLast >= $to_append->getLast)
+	    if(defined $pivot)
 	    {
-		if(defined $pivot)
-		{
 
-		    return "INCLUSION";
-		}
-		if(! $this->crosses($to_append))
-		{
-		    return "DISJUNCTION"; # internal disjunction
-		}
-		
+		return "INCLUSION";
 	    }
-	    else
+	    return "DISJUNCTION"; # internal disjunction
+	}
+	else
+	{
+	    if($this->getLast < $to_append->getLast)
 	    {
-		if($this->getLast < $to_append->getLast)
+		if (defined $pivot)
 		{
-		    if (defined $pivot)
+		    if($pivot == $this->getLast)
+			
 		    {
-			if($pivot == $this->getLast)
-			    
-			{
-			    return "INCLUSION";
-			}
-			else
-			{
-			    return "REVERSED_INCLUSION";
-			}
+			return "INCLUSION";
+		    }
+		    else
+		    {
+			return "REVERSED_INCLUSION";
 		    }
 		}
 	    }
 	}
-	if($this->getFirst >= $to_append->getFirst)
+    }
+    if($this->getFirst >= $to_append->getFirst)
+    {
+	if($this->getLast <= $to_append->getLast)
 	{
-	    if($this->getLast <= $to_append->getLast)
+	    if(defined $pivot)
 	    {
-		if(defined $pivot)
-		{
-		    return "REVERSED_INCLUSION";
-		}
-		if(! $this->crosses($to_append))
-		{
-		    return "DISJUNCTION"; # internal disjunction
-		}
+		return "REVERSED_INCLUSION";
 	    }
-	    else
+	    return "DISJUNCTION"; # internal disjunction
+	}
+	else
+	{
+	    if($this->getLast > $to_append->getLast)
 	    {
-		if($this->getLast > $to_append->getLast)
+		if (defined $pivot)
 		{
-		    if (defined $pivot)
+		    if ($pivot == $this->getFirst)
 		    {
-			if ($pivot == $this->getFirst)
-			{
-			    return "INCLUSION";  
-			}
-			else
-			{
-			    return "REVERSED_INCLUSION";
-			}
+			return "INCLUSION";  
+		    }
+		    else
+		    {
+			return "REVERSED_INCLUSION";
 		    }
 		}
 	    }
 	}
-    }   
+    }
+   
     return $mode;
 }
 
@@ -1082,52 +924,28 @@ sub getGaps
     my $counter = 0;
     my @gaps;
 
-    #  print STDERR "gG1\n";
-
     foreach $index (@{$this->getIndexes})
     {
-	#  print STDERR "gG2 (index = $index)\n";
-	#  print STDERR "gG2 (counter = $counter)\n";
-#	if (defined $previous) {print STDERR "gG2 (previous = $previous)\n";}
-	# TH - 25072007
-	if (defined $previous) {
-
-	    if ($index > $previous+1) {
-		my %gap;
-		$counter = $previous+1;
-		#  print STDERR "gG3\n";
-		while ($counter != $index)
-		{
-		    #  print STDERR "gG3 (counter = $counter)\n";
-		    
-		    $gap{$counter++} = 0;
-		}
-		#  print STDERR "gG4\n";
-		push @gaps, \%gap;
+	if(
+	    (defined $previous)
+	    &&
+	    ($index != $previous+1)
+	    )
+	{
+	    my %gap;
+	    $counter = $previous+1;
+	    while ($counter != $index)
+	    {
+		$gap{$counter++} = 0;
 	    }
+	    push @gaps, \%gap;
 	}
 	$previous = $index;
     }
-    #  print STDERR "gGF\n";
-
     return \@gaps;
 }
 
 
-sub isDiscontinuous
-{
-    my ($this) = @_;
-    my $i;
-    for ($i = 1; $i < scalar @{$this->getIndexes}; $i++)
-    {
-	if($this->getIndexes->[$i] != $this->getIndexes->[$i-1] +1)
-	{
-	    return 1;
-	}
-    }
-    return 0;
-}
-
 sub removeDoubles
 {
     my ($this) = @_;
@@ -1148,174 +966,3 @@ sub removeDoubles
 
 1;
 
-__END__
-
-=head1 NAME
-
-Lingua::YaTeA::IndexSet - Perl extension for ???
-
-=head1 SYNOPSIS
-
-  use Lingua::YaTeA::IndexSet;
-  Lingua::YaTeA::IndexSet->();
-
-=head1 DESCRIPTION
-
-
-=head1 METHODS
-
-=head2 new()
-
-
-=head2 copy()
-
-
-=head2 getIndex()
-
-
-=head2 getIndexes()
-
-
-=head2 getLast()
-
-
-=head2 getFirst()
-
-
-=head2 appearsIn()
-
-
-=head2 searchSubIndexesSet()
-
-
-=head2 isCoveredBy()
-
-
-=head2 isDisjuncted()
-
-
-=head2 getIncluded()
-
-
-=head2 isIncluded()
-
-
-=head2 checkInclusion()
-
-
-=head2 appendPosition()
-
-
-=head2 adjunctionType()
-
-
-=head2 moreThanOneInCommon()
-
-
-=head2 searchSubIndexes()
-
-
-=head2 testSyntacticBreakAndRepetition()
-
-
-=head2 buildIFSequence()
-
-
-=head2 buildPOSSequence()
-
-
-=head2 buildLFSequence()
-
-
-=head2 buildLinguisticKey()
-
-
-=head2 chooseBestSource()
-
-
-=head2 sortIslands()
-
-
-=head2 joinAll()
-
-
-=head2 fill()
-
-
-=head2 getSize()
-
-
-=head2 addIndex()
-
-
-=head2 getPartial()
-
-
-=head2 simplify()
-
-
-=head2 simplifyWithSeveralPivots()
-
-
-=head2 searchPivot()
-
-
-=head2 print ()
-
-
-=head2 mergeWith()
-
-
-=head2 contains()
-
-
-=head2 indexExists()
-
-
-=head2 getIncludedContext()
-
-
-=head2 findPrevious()
-
-
-=head2 findNext()
-
-
-=head2 removeIndex()
-
-
-=head2 defineAppendMode()
-
-
-=head2 crosses()
-
-
-=head2 getGaps()
-
-
-=head2 removeDoubles()
-
-
-
-=head1 SEE ALSO
-
-Sophie Aubin and Thierry Hamon. Improving Term Extraction with
-Terminological Resources. In Advances in Natural Language Processing
-(5th International Conference on NLP, FinTAL 2006). pages
-380-387. Tapio Salakoski, Filip Ginter, Sampo Pyysalo, Tapio Pahikkala
-(Eds). August 2006. LNAI 4139.
-
-
-=head1 AUTHOR
-
-Thierry Hamon <thierry.hamon@univ-paris13.fr> and Sophie Aubin <sophie.aubin@lipn.univ-paris13.fr>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2005 by Thierry Hamon and Sophie Aubin
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.6 or,
-at your option, any later version of Perl 5 you may have available.
-
-=cut
